[![PyPI version](https://badge.fury.io/py/sos-pbs.svg)](https://badge.fury.io/py/sos-pbs)
[![Build Status](https://travis-ci.org/vatlab/sos-pbs.svg?branch=master)](https://travis-ci.org/vatlab/sos-pbs)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/46ae533bdb614265a9fe78f077e54d87)](https://www.codacy.com/app/BoPeng/sos-pbs?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=vatlab/sos-pbs&amp;utm_campaign=Badge_Grade)
[![Coverage Status](https://coveralls.io/repos/github/vatlab/sos-pbs/badge.svg)](https://coveralls.io/github/vatlab/sos-pbs)

# sos-pbs
PBS task engine for SoS. Please refer to [SoS Homepage](http://vatlab.github.io/SoS/) for details.

